@@ -15,6 +15,8 @@ class ReviewFormTestCase(TestCase):
         self.user = UserFactory()
         self.content_object = UserFactory()
         self.rating_category = RatingCategoryFactory()
+        trans = self.rating_category.translate('en-us')
+        trans.save()
 
     def test_form(self):
         form = ReviewForm(reviewed_item=self.content_object)
@@ -49,6 +51,8 @@ class ReviewFormTestCase(TestCase):
         self.assertIsNotNone(review.user, msg=('User should be existant.'))
 
         self.new_category = RatingCategoryFactory()
+        trans = self.new_category.translate('en-us')
+        trans.save()
         form = ReviewForm(instance=review, reviewed_item=self.content_object)
         self.assertEqual(
             form.initial.get('category_{0}'.format(self.rating_category.pk)),
@@ -107,3 +111,19 @@ class ReviewFormTestCase(TestCase):
         self.assertEqual(Rating.objects.all()[0].value, '3', msg=(
             'The rating\'s value should be saved.'))
         self.assertIsNone(review.user, msg=('User should be None.'))
+
+        RatingCategoryChoiceFactory(
+            ratingcategory=self.rating_category,
+            value=0, label='0',
+        )
+        data = {'content': 'foo',
+                'category_{0}'.format(self.rating_category.pk): None}
+        form = ReviewForm(reviewed_item=self.content_object, data=data)
+        self.assertFalse(form.is_valid(), msg=(
+            'You should not be able to rate a category with None if there'
+            ' is no None choice.'))
+
+        data = {'content': 'foobar'}
+        form = ReviewForm(reviewed_item=self.content_object, data=data)
+        self.assertFalse(form.is_valid(), msg=(
+            'Without any choice selected, the form should be invalid.'))
